@@ -33,6 +33,20 @@ class ModelSortSpec(SortSpec):
     model: str
 
 
+def _split_field(field: str) -> dict[str, str]:
+    # The field can name the model explicitly like
+    # Model.field
+    # Otherways the default main model will be used
+    if "." in field:
+        if field.count(".") > 1:
+            raise ValueError("In field can only be one `.`")
+
+        table, field = field.split(".")
+        return {"model": table, "field": field}
+    else:
+        return {"field": field}
+
+
 class ParsingData:
     _or: list[FilterSpec]
     _and: list[FilterSpec]
@@ -55,20 +69,6 @@ class ParsingData:
             res |= {"and": self._and}
         return res
 
-    @staticmethod
-    def __split_field(field: str) -> dict[str, str]:
-        # The field can name the model explicitly like
-        # Model.field
-        # Otherways the default main model will be used
-        if "." in field:
-            if field.count(".") > 1:
-                raise ValueError("In field can only be one `.`")
-
-            table, field = field.split(".")
-            return {"model": table, "field": field}
-        else:
-            return {"field": field}
-
     @staticmethod
     def __convert_raw(raw: AnyFilterSpec) -> FilterSpec:
         op = raw["op"]
@@ -83,7 +83,7 @@ class ParsingData:
                 "value": raw["value"],
             }
         else:
-            return ParsingData.__split_field(raw["field"]) | {  # type: ignore
+            return _split_field(raw["field"]) | {  # type: ignore
                 "op": op,
                 "value": raw["value"],
             }
@@ -141,7 +141,7 @@ class FiltrationData(BaseModel):
         arbitrary_types_allowed = True
 
     def __get_sort_spec(self) -> list[ModelSortSpec]:
-        return [self.__split_field(self.order_by) | {"direction": self.sort_by}]  # type: ignore
+        return [_split_field(self.order_by) | {"direction": self.sort_by}]  # type: ignore
 
     def apply(self, query: Query) -> DataTable:
         filter_spec = self.to_filter.to_spec()
